@@ -165,6 +165,13 @@ do
            ;;
    esac
 
+   if [ $simbin = "tsim-erc32" ]
+   then
+      simrun="run"
+   else
+      simrun="run [expr 0xff000000 & [silent ep]]"
+   fi
+
    # Change the title bar to indicate which test we are running
    # The simulator screen doesn't provide any indication
 
@@ -191,7 +198,7 @@ do
 
            # All other tests (single-processor)
            *)
-               echo "go"
+               echo "${simrun}"
                echo ""
                echo "reg"
                echo "perf"
